OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor, aguarde até que a mesma esteja concluída..",
    "Migration started …" : "Migração iniciada...",
    "Saved" : "Guardado",
    "Not saved" : "Não guardado",
    "Sending…" : "A enviar...",
    "Email sent" : "Mensagem de correio eletrónico enviada",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ocorreu um erro. Por favor, envie um certificado PEM codificado em ASCII.",
    "Valid until {date}" : "Válida até {date}",
    "Delete" : "Apagar",
    "Local" : "Local",
    "Private" : "Privado",
    "Only visible to local users" : "Apenas visível para utilizadores locais",
    "Only visible to you" : "Apenas visível por si",
    "Contacts" : "Contactos",
    "Visible to local users and to trusted servers" : "Visível por utilizadores locais e servidores confiáveis",
    "Public" : "Público",
    "Will be synced to a global and public address book" : "Será sincronizado com um livro de endereços público e global",
    "Verify" : "Verificar",
    "Verifying …" : "A verificar...",
    "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
    "Very weak password" : "Palavra-passe muito fraca",
    "Weak password" : "Palavra-passe fraca",
    "So-so password" : "Palavra-passe aceitável",
    "Good password" : "Palavra-passe boa",
    "Strong password" : "Palavra-passe forte",
    "Select a profile picture" : "Selecione uma fotografia de perfil",
    "Groups" : "Grupos",
    "{actor} changed your password" : "{actor} alterou a sua senha",
    "You changed your password" : "Você alterou a sua senha",
    "Your password was reset by an administrator" : "A sua senha foi alterada por um administrador",
    "{actor} changed your email address" : "{actor} alterou o seu endereço de e-mail",
    "You changed your email address" : "Você alterou o seu endereço de e-mail",
    "Your email address was changed by an administrator" : "O seu endereço de e-mail foi alterado por um administrador",
    "Security" : "Segurança",
    "You successfully logged in using two-factor authentication (%1$s)" : "Autenticado com sucesso utilizando autenticação de dois factores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Tentativa falhada de autenticação utilizando dois factores (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "A <strong>password</strong> ou <strong>email</strong> foram modificados",
    "Couldn't remove app." : "Não foi possível remover a aplicação.",
    "Couldn't update app." : "Não foi possível atualizar a app.",
    "Wrong password" : "Palavra-passe errada",
    "No user supplied" : "Nenhum utilizador especificado",
    "Authentication error" : "Erro na autenticação",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor introduza uma senha administrativa de recuperação ou todos os dados de utilizador serão perdidos.",
    "Wrong admin recovery password. Please check the password and try again." : "Palavra-passe de recuperação do administrador errada. Por favor, verifique a palavra-passe e tente novamente.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "O Backend não suporta modificar senhas, mas a chave de cifra do utilizador foi actualizada.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "A instalar e a atualizar as aplicações através da loja de aplicações ou Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Invalid SMTP password." : "Senha de SMTP inválida.",
    "Email setting test" : "Teste definições de email",
    "Well done, %s!" : "Muito bem, %s!",
    "If you received this email, the email configuration seems to be correct." : "Se recebeu este email, a configuração do serviço de email deverá estar correcta.",
    "Email could not be sent. Check your mail server log" : "O email não pode ser enviado. Por favor verifique os logs do seu servidor de e-mail.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu um problema ao enviar o e-mail. Por favor verifique as suas definições. (Erro: %s)",
    "You need to set your user email before being able to send test emails." : "Você tem de configurar o seu e-mail de utilizador antes de ser capaz de enviar e-mails de teste",
    "Invalid mail address" : "Endereço de correio eletrónico inválido",
    "Settings saved" : "Definições guardadas",
    "Unable to change full name" : "Não foi possível alterar o seu nome completo",
    "Unable to change email address" : "Não foi possível alterar o seu endereço de e-mail",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Por forma a validar a sua conta de Twitter, por favor publique o seguinte Twitter ( garanta que a publicação não contém quebras de linha):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Por forma de validar o Website, por favor publique o conteúdo seguinte na sua raiz em 'well-known/CloudIdVerificationCode.txt' (garanta que o texto completo se encontra numa única linha):",
    "%1$s changed your password on %2$s." : "%1$s modificou a sua senha em %2$s.",
    "Your password on %s was changed." : "A sua senha para %s foi modificada.",
    "Your password on %s was reset by an administrator." : "A sua senha para  %s foi redefinida pelo administrador.",
    "Password for %1$s changed on %2$s" : "A senha para %1$s foi modificada em %2$s",
    "Password changed for %s" : "Senha modificada para %s",
    "If you did not request this, please contact an administrator." : "Se não requereu isto por favor contacte um administrador.",
    "Your email address on %s was changed." : "O endereço de e-mail me %s foi modificado.",
    "Your email address on %s was changed by an administrator." : "O seu endereço de email em %s foi modificado por um administrador.",
    "Email address for %1$s changed on %2$s" : "Endereço de e-mail para %1$s modificado em %2$s",
    "Email address changed for %s" : "Endereço de e-mail modificado para %s",
    "The new email address is %s" : "O novo endereço de e-mail é %s",
    "Your %s account was created" : "A tua conta %s foi criada",
    "Welcome aboard" : "Bem-vindo a bordo",
    "Welcome aboard %s" : "Bem-vindo a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bem-vindo à conta %s, aqui pode adicionar, proteger e partilhar os seus dados.",
    "Your username is: %s" : "O seu utilizador é: %s",
    "Set your password" : "Escolher senha",
    "Go to %s" : "Ir para %s",
    "Install Client" : "Instalar cliente",
    "Unlimited" : "Ilimitado",
    "Limit to groups" : "Limitado a grupos",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "As apps oficiais são desenvolvidas de e para a comunidade. Oferecem um repositório central de funcionalidades e estão preparadas para uso em produção.",
    "Official" : "Oficial",
    "Remove" : "Remover",
    "Disable" : "Desativar",
    "All" : "Todos",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
    "View in store" : "Ver na loja",
    "Visit website" : "Visitar o website",
    "Report a bug" : "Reportar um erro",
    "User documentation" : "Documentação de Utilizador",
    "Admin documentation" : "Documentação do Administrador",
    "Developer documentation" : "Documentação de Programador",
    "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
    "Enable all" : "Ativar todas",
    "Download and enable" : "Transferir e ativar",
    "Enable" : "Ativar",
    "The app will be downloaded from the app store" : "A aplicação será transferida da loja de aplicações",
    "Allow filesystem access" : "Permitir acesso ao sistema de ficheiros",
    "Revoke" : "Revogar",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Microsoft Edge",
    "Firefox" : "Mozilla Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome para Android",
    "Sync client - {os}" : "Sincronizar cliente - {so}",
    "This session" : "Esta sessão",
    "Device" : "Dispositivo",
    "Last activity" : "Última atividade",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, desktop e clientes móveis estão actualmente autenticados na sua conta.",
    "Error while creating device token" : "Erro durante a criação do token do dispositivo",
    "Error while deleting the token" : "Erro durante a eliminação do token",
    "App name" : "Nome da App",
    "Create new app password" : "Criar nova palavra-passe de aplicação",
    "Use the credentials below to configure your app or device." : "Use as credenciais abaixo para configurar a sua app ou dispositivo.",
    "For security reasons this password will only be shown once." : "Por motivos de segurança a sua password só será mostrada uma vez.",
    "Username" : "Nome de utilizador",
    "Password" : "Palavra-passe",
    "Done" : "Concluído",
    "Copied!" : "Copiado!",
    "Copy" : "Copiar",
    "New password" : "Nova palavra-passe",
    "{size} used" : "{size} utilizado",
    "Email" : "Email",
    "Group admin for" : "Administrador de grupo para",
    "Quota" : "Quota",
    "Language" : "Idioma",
    "Storage location" : "Localização do armazenamento",
    "User backend" : "Backend do utilizador",
    "Last login" : "Último início de sessão",
    "Default quota" : "Quota padrão",
    "Your apps" : "As suas apps",
    "Disabled apps" : "Apps desativadas",
    "Updates" : "Actualizações",
    "App bundles" : "Pacotes de apps",
    "Show last login" : "Mostrar último login",
    "Show user backend" : "Mostrar interface do utilizador",
    "Admins" : "Administrador",
    "Everyone" : "Para todos",
    "Add group" : "Adicionar grupo",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A app foi activada mas necessita ser actualizada. Irá ser redireccionado para a página de actualização em 5 segundos.",
    "App update" : "Actualização de app",
    "Error: This app can not be enabled because it makes the server unstable" : "Erro: Esta app não pode ser activada porque torna o servidor instável.",
    "SSL Root Certificates" : "Certificados SSL Root",
    "Common Name" : "Nome Comum",
    "Valid until" : "Válido até",
    "Issued By" : "Emitido Por",
    "Valid until %s" : "Válido até %s",
    "Import root certificate" : "Importar certificado root",
    "Administrator documentation" : "Documentação de Administrador.",
    "Forum" : "Fórum",
    "None" : "Nenhum",
    "Login" : "Iniciar Sessão",
    "Plain" : "Plano",
    "NT LAN Manager" : "Gestor de REDE NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servidor de Correio Eletrónico",
    "Open documentation" : "Abrir documentação",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "É importante configurar este servidor para ser possível enviar emails, possibilitando enviar notificações bem como possibilitar a recuperação de senhas.",
    "Send mode" : "Modo de Envio",
    "Encryption" : "Encriptação",
    "From address" : "Do endereço",
    "mail" : "Correio",
    "Authentication method" : "Método de Autenticação",
    "Authentication required" : "Autenticação necessária",
    "Server address" : "Endereço do Servidor",
    "Port" : "Porta",
    "Credentials" : "Credenciais",
    "SMTP Username" : "Nome de utilizador SMTP",
    "SMTP Password" : "Palavra-passe SMTP",
    "Test email settings" : "Testar definições de e-mail",
    "Send email" : "Enviar email",
    "Security & setup warnings" : "Avisos de configuração e segurança",
    "All checks passed." : "Todas as verificações passaram.",
    "Version" : "Versão",
    "Server-side encryption" : "Atualizar App",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A cifra do lado do servidor possibilita cifrar os ficheiros que serão enviados para este servidor. Isto implica um impacto no desempenho e só deverá ser activo quando necessário.",
    "Enable server-side encryption" : "Ativar encriptação do lado do servidor",
    "Please read carefully before activating server-side encryption: " : "Por favor, leia cuidadosamente antes de ativar a encriptação do lado do servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Uma vez ativada a encriptação, todos os ficheiros carregados para o servidor a partir deste ponto serão encriptados pelo servidor. Só será possível desativar a encriptação numa data mais tarde se o módulo de encriptação ativo suportar essa função, assim como todas as pré-condições (e.g. definir chave de recuperação) sejam cumpridas.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "A cifra por si só não garante a segurança do sistema. Por favor consulte a documentação para mais detalhes sobre a aplicação de cifra e os casos de uso suportados.",
    "Be aware that encryption always increases the file size." : "Tenha em conta que a encriptação aumenta sempre o tamanho do ficheiro.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar cópias de segurança regulares dos seus dados, em caso de encriptação tenha a certeza de que faz cópia das chaves de encriptação em conjunto com os seus dados.",
    "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: quer mesmo ativar a encriptação?",
    "Enable encryption" : "Ativar a encriptação",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de encriptação carregador, por favor ative um módulo de encriptação no menu das aplicações.",
    "Select default encryption module:" : "Selecionar o módulo de encriptação predefinido:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Precisa de migrar as suas chaves de encriptação da encriptação antiga (ownCloud <= 8.0) para a nova. Por favor, ative o \"Módulo de encriptação predefinido\" e execute 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Precisa de migrar as suas chaves de encriptação da encriptação antiga (ownCloud <= 8.0) para a nova.",
    "Start migration" : "Iniciar migração",
    "Background jobs" : "Tarefas de segundo plano",
    "Last job ran %s." : "Última tarefa executada: %s.",
    "Last job execution ran %s. Something seems wrong." : "Última execução da tarefa: %s. Houve algum problema. ",
    "Background job didn’t run yet!" : "Tarefa de segundo plano ainda não foi executada!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Para desempenho óptimo é importante que configura as tarefas de segundo plano correctamente. Para maiores instâncias a definição recomendada é 'Cron'. Por favor veja a documentação para mais informações.",
    "Execute one task with each page loaded" : "Executar uma tarefa com cada página carregada",
    "The cron.php needs to be executed by the system user \"%s\"." : "O cron.php precisa de ser executado pelo utilizador do sistema \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para esta execução precisa da extensão PHP POSIX. Veja {iniciodaligação}documentação PHP{fimdaligação} para mais mais detalhes.",
    "Sharing" : "Partilha",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador pode afinar o comportamento de partilha. Por favor veja a documentação para mais informação.",
    "Allow apps to use the Share API" : "Permitir que os utilizadores usem a API de partilha",
    "Allow users to share via link" : "Permitir que os utilizadores partilhem através do link",
    "Allow public uploads" : "Permitir Envios Públicos",
    "Always ask for a password" : "Pedir sempre a senha",
    "Enforce password protection" : "Forçar proteção por palavra-passe",
    "Set default expiration date" : "Especificar a data padrão de expiração",
    "Expire after " : "Expira após",
    "days" : "dias",
    "Enforce expiration date" : "Forçar a data de expiração",
    "Allow resharing" : "Permitir repartilha",
    "Allow sharing with groups" : "Permitir partilha com grupos.",
    "Restrict users to only share with users in their groups" : "Restringe os utilizadores só a partilhar com utilizadores do seu grupo",
    "Exclude groups from sharing" : "Excluir grupos das partilhas",
    "These groups will still be able to receive shares, but not to initiate them." : "Estes grupos poderão receber partilhas, mas não poderão iniciá-las.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "permitir completar automáticamente nome do utilizador no diálogo de partilha. Se isto estiver inactivo é necessário introduzir o nome do utilizador ou o endereço de e-mail completo. ",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Mostrar aviso legal na página de carregamento de ligações públicas. (Mostrar apenas quando a lista de ficheiros estiver oculta.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto será exibido na página de carregamento de ligações públicas quando a lista de ficheiros estiver oculta. ",
    "Personal" : "Pessoal",
    "Administration" : "Administração",
    "Like our Facebook page" : "Deixe um Gosto na nossa página do Facebook",
    "Follow us on Twitter" : "Siga-nos no Twitter",
    "Check out our blog" : "Veja o nosso blog",
    "Subscribe to our newsletter" : "Subscreva as nossas notícias",
    "Profile picture" : "Foto do perfil",
    "Upload new" : "Carregar novo",
    "Select from Files" : "Seleccione dos Ficheiros",
    "Remove image" : "Remover imagem",
    "png or jpg, max. 20 MB" : "png ou jpg, máx. 20 MB",
    "Picture provided by original account" : "Imagem fornecida pela conta original",
    "Cancel" : "Cancelar",
    "Choose as profile picture" : "Escolher como fotografia de perfil",
    "Full name" : "Nome completo",
    "No display name set" : "Nenhum nome display estabelecido",
    "Your email address" : "O seu endereço de email",
    "No email address set" : "Nenhum endereço de email estabelecido",
    "For password reset and notifications" : "Para recuperação de senhas e notificações",
    "Phone number" : "Número de telefone",
    "Your phone number" : "O seu número de telefone",
    "Address" : "Morada",
    "Your postal address" : "A sua morada",
    "Website" : "Website",
    "It can take up to 24 hours before the account is displayed as verified." : "Pode levar até 24 horas para que a conta seja mostrada como verificada.",
    "Link https://…" : "Ligação https:// ...",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Identificador do Twitter  @...",
    "Help translate" : "Ajude a traduzir",
    "Current password" : "Palavra-passe atual",
    "Change password" : "Alterar palavra-passe",
    "Store credentials" : "Armazenar credenciais",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php está registada num serviço webcron para chamar cron.php a cada 15 minutos através de HTTP.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Use o serviço de tarefas automáticas para chamar o ficheiro cron.php a cada 15 minutos."
},
"nplurals=2; plural=(n != 1);");
